<?php

namespace Drupal\commerce_fedex_test;

use Drupal\Tests\commerce_fedex\Kernel\FedExKernelTestBase;
use NicholasCreativeMedia\FedExPHP\Services\RateService;
use NicholasCreativeMedia\FedExPHP\Structs\RateRequest;

/**
 * A class to simulate a FedEx Rate Request.
 */
class TestRateService extends RateService {

  /**
   * Function getRates simulate a fedex rate request.
   *
   * @param \NicholasCreativeMedia\FedExPHP\Structs\RateRequest $rateRequest
   *   A rate Request object.
   *
   * @return mixed|string
   *   A simulated response based on the request.
   */
  public function getRates(RateRequest $rateRequest) {
    $authenticated = $rateRequest->getWebAuthenticationDetail()->getUserCredential()->getKey() == FedExKernelTestBase::TEST_KEY;
    $authenticated &= $rateRequest->getWebAuthenticationDetail()->getUserCredential()->getPassword() == FedExKernelTestBase::TEST_PASS;
    $authenticated &= $rateRequest->getClientDetail()->getAccountNumber() == FedExKernelTestBase::TEST_ACCOUNT_NUMBER;
    $authenticated &= $rateRequest->getClientDetail()->getMeterNumber() == FedExKernelTestBase::TEST_METER_NUMBER;
    if (!$authenticated) {
      return $this->authenticationFailed();
    }

    /*TODO add more validation */
    return $this->allInOneResults();

  }

  /**
   * Return a simulated authentication failed response.
   *
   * @return string
   *   a simulated authentication failed response.
   */
  private function authenticationFailed() {
    return "O:48:\"NicholasCreativeMedia\FedExPHP\Structs\RateReply\":5:{s:15:\"HighestSeverity\";s:5:\"ERROR\";s:13:\"Notifications\";a:1:{i:0;O:51:\"NicholasCreativeMedia\FedExPHP\Structs\Notification\":6:{s:8:\"Severity\";s:5:\"ERROR\";s:6:\"Source\";s:4:\"prof\";s:4:\"Code\";s:4:\"1000\";s:7:\"Message\";s:21:\"Authentication Failed\";s:16:\"LocalizedMessage\";N;s:17:\"MessageParameters\";N;}}s:7:\"Version\";O:48:\"NicholasCreativeMedia\FedExPHP\Structs\VersionId\":4:{s:9:\"ServiceId\";s:3:\"crs\";s:5:\"Major\";i:20;s:12:\"Intermediate\";i:0;s:5:\"Minor\";i:0;}s:17:\"TransactionDetail\";N;s:16:\"RateReplyDetails\";N;}";
  }

  /**
   * Return a simulated valid response.
   *
   * @return string
   *   a simulated valid response.
   */
  private function allInOneResults() {
    return unserialize("O:48:\"NicholasCreativeMedia\FedExPHP\Structs\RateReply\":5:{s:15:\"HighestSeverity\";s:7:\"SUCCESS\";s:13:\"Notifications\";a:1:{i:0;O:51:\"NicholasCreativeMedia\FedExPHP\Structs\Notification\":6:{s:8:\"Severity\";s:7:\"SUCCESS\";s:6:\"Source\";s:3:\"crs\";s:4:\"Code\";s:1:\"0\";s:7:\"Message\";s:36:\"Request was successfully processed. \";s:16:\"LocalizedMessage\";s:36:\"Request was successfully processed. \";s:17:\"MessageParameters\";N;}}s:7:\"Version\";O:48:\"NicholasCreativeMedia\FedExPHP\Structs\VersionId\":4:{s:9:\"ServiceId\";s:3:\"crs\";s:5:\"Major\";i:20;s:12:\"Intermediate\";i:0;s:5:\"Minor\";i:0;}s:17:\"TransactionDetail\";N;s:16:\"RateReplyDetails\";a:7:{i:0;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:15:\"FIRST_OVERNIGHT\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:1:\"6\";s:8:\"RateZone\";s:2:\"02\";s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"61.51\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"61.51\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"2.0\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"63.51\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"63.51\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"63.51\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"2.0\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"61.51\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"61.51\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"2.0\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"63.51\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"63.51\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"2.0\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:1;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:18:\"PRIORITY_OVERNIGHT\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:1:\"1\";s:8:\"RateZone\";N;s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.25\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.25\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"1.02\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"32.27\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"32.27\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"32.27\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"1.02\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.25\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.25\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"1.02\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"32.27\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"32.27\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"1.02\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:2;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:18:\"STANDARD_OVERNIGHT\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:4:\"1283\";s:8:\"RateZone\";s:2:\"02\";s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"30.44\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"30.44\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.99\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.43\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.43\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.43\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.99\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"30.44\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"30.44\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.99\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.43\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"31.43\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.99\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:3;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:14:\"FEDEX_2_DAY_AM\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:1:\"4\";s:8:\"RateZone\";s:2:\"02\";s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"19.62\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"19.62\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.64\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"20.26\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"20.26\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"20.26\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.64\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"19.62\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"19.62\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.64\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"20.26\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"20.26\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.64\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:4;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:11:\"FEDEX_2_DAY\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:4:\"5980\";s:8:\"RateZone\";s:2:\"02\";s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"17.58\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"17.58\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.57\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"18.15\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"18.15\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"18.15\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.57\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"17.58\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"17.58\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.57\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"18.15\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"18.15\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.57\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:5;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:19:\"FEDEX_EXPRESS_SAVER\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";s:2:\"A1\";s:22:\"DestinationServiceArea\";s:2:\"A4\";s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";s:4:\"7167\";s:8:\"RateZone\";s:2:\"02\";s:11:\"PricingCode\";s:7:\"PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:4:\"3.25\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"15.8\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"15.8\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.51\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"16.31\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"16.31\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"16.31\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.51\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:3:\"1.6\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"15.8\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"15.8\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.51\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"16.31\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:5:\"16.31\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.51\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";N;s:11:\"Description\";s:4:\"Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}i:6;O:54:\"NicholasCreativeMedia\FedExPHP\Structs\RateReplyDetail\":17:{s:11:\"ServiceType\";s:12:\"FEDEX_GROUND\";s:13:\"PackagingType\";s:14:\"YOUR_PACKAGING\";s:14:\"AppliedOptions\";N;s:17:\"AppliedSubOptions\";N;s:15:\"DeliveryStation\";N;s:17:\"DeliveryDayOfWeek\";N;s:17:\"DeliveryTimestamp\";N;s:13:\"CommitDetails\";N;s:20:\"DestinationAirportId\";s:3:\"GRR\";s:31:\"IneligibleForMoneyBackGuarantee\";b:0;s:17:\"OriginServiceArea\";N;s:22:\"DestinationServiceArea\";N;s:11:\"TransitTime\";N;s:18:\"MaximumTransitTime\";N;s:15:\"SignatureOption\";s:15:\"SERVICE_DEFAULT\";s:14:\"ActualRateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:20:\"RatedShipmentDetails\";a:1:{i:0;O:58:\"NicholasCreativeMedia\FedExPHP\Structs\RatedShipmentDetail\":4:{s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:18:\"ShipmentRateDetail\";O:57:\"NicholasCreativeMedia\FedExPHP\Structs\ShipmentRateDetail\":35:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:9:\"RateScale\";N;s:8:\"RateZone\";s:1:\"2\";s:11:\"PricingCode\";N;s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:20:\"CurrencyExchangeRate\";N;s:20:\"SpecialRatingApplied\";N;s:10:\"DimDivisor\";i:0;s:14:\"DimDivisorType\";N;s:20:\"FuelSurchargePercent\";s:3:\"4.0\";s:18:\"TotalBillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"LB\";s:5:\"Value\";s:3:\"4.0\";}s:14:\"TotalDimWeight\";N;s:15:\"TotalBaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.44\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:15:\"TotalNetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.44\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.34\";}s:19:\"TotalNetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.78\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:14:\"TotalNetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.78\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:19:\"TotalDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:26:\"TotalAncillaryFeesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:23:\"TotalDutiesTaxesAndFees\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:32:\"TotalNetChargeWithDutiesAndTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.78\";}s:22:\"ShipmentLegRateDetails\";N;s:17:\"FreightRateDetail\";N;s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.34\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";s:7:\"PACKAGE\";s:11:\"Description\";s:17:\"FedEx Ground Fuel\";}}s:5:\"Taxes\";N;s:14:\"DutiesAndTaxes\";N;s:21:\"AncillaryFeesAndTaxes\";N;s:23:\"VariableHandlingCharges\";N;s:28:\"TotalVariableHandlingCharges\";N;}s:13:\"RatedPackages\";a:1:{i:0;O:57:\"NicholasCreativeMedia\FedExPHP\Structs\RatedPackageDetail\":6:{s:11:\"TrackingIds\";N;s:11:\"GroupNumber\";i:0;s:20:\"EffectiveNetDiscount\";N;s:27:\"AdjustedCodCollectionAmount\";N;s:13:\"OversizeClass\";N;s:17:\"PackageRateDetail\";O:56:\"NicholasCreativeMedia\FedExPHP\Structs\PackageRateDetail\":19:{s:8:\"RateType\";s:21:\"PAYOR_ACCOUNT_PACKAGE\";s:17:\"RatedWeightMethod\";s:6:\"ACTUAL\";s:17:\"MinimumChargeType\";N;s:13:\"BillingWeight\";O:45:\"NicholasCreativeMedia\FedExPHP\Structs\Weight\":2:{s:5:\"Units\";s:2:\"KG\";s:5:\"Value\";s:4:\"1.81\";}s:9:\"DimWeight\";N;s:14:\"OversizeWeight\";N;s:10:\"BaseCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.44\";}s:21:\"TotalFreightDiscounts\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:10:\"NetFreight\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.44\";}s:15:\"TotalSurcharges\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.34\";}s:14:\"NetFedExCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.78\";}s:10:\"TotalTaxes\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:9:\"NetCharge\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"8.78\";}s:12:\"TotalRebates\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:3:\"0.0\";}s:16:\"FreightDiscounts\";N;s:7:\"Rebates\";N;s:10:\"Surcharges\";a:1:{i:0;O:48:\"NicholasCreativeMedia\FedExPHP\Structs\Surcharge\":4:{s:6:\"Amount\";O:44:\"NicholasCreativeMedia\FedExPHP\Structs\Money\":2:{s:8:\"Currency\";s:3:\"USD\";s:6:\"Amount\";s:4:\"0.34\";}s:13:\"SurchargeType\";s:4:\"FUEL\";s:5:\"Level\";s:7:\"PACKAGE\";s:11:\"Description\";s:17:\"FedEx Ground Fuel\";}}s:5:\"Taxes\";N;s:23:\"VariableHandlingCharges\";N;}}}}}}}}");
  }

}
